@@ -265,7 +265,6 @@ class PyzoEditor(BaseTextCtrl):
         self._name = '<TMP>'
 
         # View settings
-        self.setShowWhitespace(pyzo.config.view.showWhitespace)
         #TODO: self.setViewWrapSymbols(view.showWrapSymbols)
         self.setShowLineEndings(pyzo.config.view.showLineEndings)
         self.setShowIndentationGuides(pyzo.config.view.showIndentationGuides)
@@ -273,7 +272,6 @@ class PyzoEditor(BaseTextCtrl):
         self.setWrap(bool(pyzo.config.view.wrap))
         self.setHighlightCurrentLine(pyzo.config.view.highlightCurrentLine)
         self.setLongLineIndicatorPosition(pyzo.config.view.edgeColumn)
-        self.setHighlightMatchingBracket(pyzo.config.view.highlightMatchingBracket)
         #TODO: self.setFolding( int(view.codeFolding)*5 )
         # bracematch is set in baseTextCtrl, since it also applies to shells
         # dito for zoom and tabWidth
@@ -630,6 +628,7 @@ class PyzoEditor(BaseTextCtrl):
         Comment the lines that are currently selected
         """
         indents = []
+        indentChar = ' ' if self.indentUsingSpaces() else '\t'
 
         def getIndent(cursor):
             text = cursor.block().text().rstrip()
@@ -637,6 +636,13 @@ class PyzoEditor(BaseTextCtrl):
                 indents.append(len(text) - len(text.lstrip()))
 
         def commentBlock(cursor):
+            blockText = cursor.block().text()
+            numMissingIndentChars = (minindent -
+                (len(blockText) - len(blockText.lstrip(indentChar))))
+            if numMissingIndentChars > 0:
+                # Prevent setPosition from leaving bounds of the current block
+                # if there are too few indent characters (e.g. an empty line)
+                cursor.insertText(indentChar * numMissingIndentChars)
             cursor.setPosition(cursor.block().position() + minindent)
             cursor.insertText('# ')
 
